@@ -193,7 +193,20 @@ class DynamoDBStreamsToLambda(
         :summary: Constructs a new instance of the LambdaToDynamoDB class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DynamoDBStreamsToLambda.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
+                dynamo_event_source_props: typing.Any = None,
+                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DynamoDBStreamsToLambdaProps(
@@ -267,7 +280,18 @@ class DynamoDBStreamsToLambdaProps:
         if isinstance(sqs_dlq_queue_props, dict):
             sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
         if __debug__:
-            type_hints = typing.get_type_hints(DynamoDBStreamsToLambdaProps.__init__)
+            def stub(
+                *,
+                deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
+                dynamo_event_source_props: typing.Any = None,
+                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument deploy_sqs_dlq_queue", value=deploy_sqs_dlq_queue, expected_type=type_hints["deploy_sqs_dlq_queue"])
             check_type(argname="argument dynamo_event_source_props", value=dynamo_event_source_props, expected_type=type_hints["dynamo_event_source_props"])
             check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
